From 57e9c43958e57a76e215b7fb9a97ab52c8e5d2d9 Mon Sep 17 00:00:00 2001
From: Greg Hogan <code@greghogan.com>
Date: Tue, 5 Oct 2021 17:55:04 +0000
Subject: [PATCH] gnu: ceph: Fix breaking change in snappy.

* gnu/packages/storage.scm (ceph)[source]: Add patch.
* gnu/packages/patches/ceph-fix-snappy-breaking-change.patch: New file.
* gnu/local.mk: Add it.
---
 gnu/local.mk                                        |  1 +
 .../patches/ceph-fix-snappy-breaking-change.patch   | 13 +++++++++++++
 gnu/packages/storage.scm                            |  5 ++++-
 3 files changed, 18 insertions(+), 1 deletion(-)
 create mode 100644 gnu/packages/patches/ceph-fix-snappy-breaking-change.patch

diff --git a/gnu/local.mk b/gnu/local.mk
index 91915e780b..73995eec2c 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -919,6 +919,7 @@ dist_patch_DATA =						\
   %D%/packages/patches/cdparanoia-fpic.patch			\
   %D%/packages/patches/cdrtools-3.01-mkisofs-isoinfo.patch 	\
   %D%/packages/patches/ceph-disable-cpu-optimizations.patch	\
+  %D%/packages/patches/ceph-fix-snappy-breaking-change.patch	\
   %D%/packages/patches/chez-scheme-build-util-paths-backport.patch      \
   %D%/packages/patches/chmlib-inttypes.patch			\
   %D%/packages/patches/cl-asdf-config-directories.patch		\
diff --git a/gnu/packages/patches/ceph-fix-snappy-breaking-change.patch b/gnu/packages/patches/ceph-fix-snappy-breaking-change.patch
new file mode 100644
index 0000000000..7a10e2e4ae
--- /dev/null
+++ b/gnu/packages/patches/ceph-fix-snappy-breaking-change.patch
@@ -0,0 +1,13 @@
+Patch tracked upstream at https://tracker.ceph.com/issues/50934
+
+--- a/src/compressor/snappy/SnappyCompressor.h
++++ b/src/compressor/snappy/SnappyCompressor.h
+@@ -96,7 +96,7 @@ class SnappyCompressor : public Compressor {
+     if (qat_enabled)
+       return qat_accel.decompress(p, compressed_len, dst);
+ #endif
+-    snappy::uint32 res_len = 0;
++    uint32_t res_len = 0;
+     BufferlistSource source_1(p, compressed_len);
+     if (!snappy::GetUncompressedLength(&source_1, &res_len)) {
+       return -1;
diff --git a/gnu/packages/storage.scm b/gnu/packages/storage.scm
index d53327df75..4dfae1e80e 100644
--- a/gnu/packages/storage.scm
+++ b/gnu/packages/storage.scm
@@ -2,6 +2,7 @@
 ;;; Copyright © 2017, 2018, 2019, 2020 Marius Bakke <mbakke@fastmail.com>
 ;;; Copyright © 2017 Rutger Helling <rhelling@mykolab.com>
 ;;; Copyright © 2020 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2021 Greg Hogan <code@greghogan.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -64,7 +65,9 @@
                (base32
                 "0lmdri415hqczc9565s5m5568pnj97ipqxgnw6085kps0flwq5zh"))
               (patches
-               (search-patches "ceph-disable-cpu-optimizations.patch"))
+               (search-patches
+                "ceph-disable-cpu-optimizations.patch"
+                "ceph-fix-snappy-breaking-change.patch"))
               (modules '((guix build utils)))
               (snippet
                '(begin
-- 
2.33.0

